@@ -1,21 +1,27 @@
+import freeorion as fo
 import random
 import sys
 from itertools import product
 
-import freeorion as fo
-
 import planets
 import universe_tables
+
 import util
 
-
 # tuple of available star types
-star_types = (fo.starType.blue, fo.starType.white, fo.starType.yellow, fo.starType.orange,
-              fo.starType.red, fo.starType.neutron, fo.starType.blackHole, fo.starType.noStar)
+star_types = (
+    fo.starType.blue,
+    fo.starType.white,
+    fo.starType.yellow,
+    fo.starType.orange,
+    fo.starType.red,
+    fo.starType.neutron,
+    fo.starType.blackHole,
+    fo.starType.noStar,
+)
 
 # tuple of "real" star types (that is, blue to red, not neutron, black hole or even no star)
-star_types_real = (fo.starType.blue, fo.starType.white, fo.starType.yellow,
-                   fo.starType.orange, fo.starType.red)
+star_types_real = (fo.starType.blue, fo.starType.white, fo.starType.yellow, fo.starType.orange, fo.starType.red)
 
 
 def pick_star_type(galaxy_age):
@@ -29,9 +35,11 @@ def pick_star_type(galaxy_age):
     try:
         max_roll = 0
         for candidate in star_types:
-            roll = random.randint(1, 100) \
-                + universe_tables.UNIVERSE_AGE_MOD_TO_STAR_TYPE_DIST[galaxy_age][candidate] \
+            roll = (
+                random.randint(1, 100)
+                + universe_tables.UNIVERSE_AGE_MOD_TO_STAR_TYPE_DIST[galaxy_age][candidate]
                 + universe_tables.BASE_STAR_TYPE_DIST[candidate]
+            )
             if max_roll < roll:
                 max_roll = roll
                 star_type = candidate
@@ -58,7 +66,7 @@ def name_planets(system):
     # iterate over all planets in the system
     sys_name = fo.get_name(system)
     for planet in fo.sys_get_planets(system):
-        name = fo.user_string("NEW_PLANET_NAME")
+        name = fo.userString("NEW_PLANET_NAME")
         name = name.replace("%1%", sys_name)
         name = name.replace("%2%", fo.planet_cardinal_suffix(planet))
         name = name.strip()
@@ -85,8 +93,11 @@ def generate_systems(pos_list, gsd):
         system = fo.create_system(star_type, "", position[0], position[1])
         if system == fo.invalid_object():
             # create system failed, report an error and try to continue with next position
-            util.report_error("Python generate_systems: create system at position (%f, %f) failed"
-                              % (position[0], position[1]))
+            util.report_error(
+                "Python generate_systems: create system at position ({:f}, {:f}) failed".format(
+                    position[0], position[1]
+                )
+            )
             continue
         sys_list.append(system)
 
@@ -115,7 +126,12 @@ def generate_systems(pos_list, gsd):
                 break
         else:
             # Intentionally non-modal.  Should be a warning.
-            print(("Python generate_systems: place planets in system %d at position (%.2f, %.2f) failed"
-                   % (system, position[0], position[1])), file=sys.stderr)
+            print(
+                (
+                    "Python generate_systems: place planets in system %d at position (%.2f, %.2f) failed"
+                    % (system, position[0], position[1])
+                ),
+                file=sys.stderr,
+            )
 
     return sys_list
