@@ -2,14 +2,14 @@ from common.base_prod import TECH_COST_MULTIPLIER
 from techs.ship_weapons.ship_weapons import WEAPON_UPGRADE_CAPACITY_EFFECTS
 
 Tech(
-    name="SHP_WEAPON_3_4",
-    description="SHP_WEAPON_3_4_DESC",
+    name="SHP_WEAPON_1_4",
+    description="SHP_WEAPON_1_4_DESC",
     short_description="SHIP_WEAPON_IMPROVE_SHORT_DESC",
     category="SHIP_WEAPONS_CATEGORY",
-    researchcost=400 * TECH_COST_MULTIPLIER,
+    researchcost=20 * TECH_COST_MULTIPLIER,
     researchturns=2,
     tags=["PEDIA_SR_WEAPON_TECHS"],
-    prerequisites=["SHP_WEAPON_3_3"],
-    effectsgroups=WEAPON_UPGRADE_CAPACITY_EFFECTS("SHP_WEAPON_3_4", "SR_WEAPON_3_1", 3),
-    graphic="icons/ship_parts/plasma-4.png",
+    prerequisites=["SHP_WEAPON_1_3"],
+    effectsgroups=WEAPON_UPGRADE_CAPACITY_EFFECTS("SHP_WEAPON_1_4", "SR_WEAPON_1_1", 1),
+    graphic="icons/ship_parts/mass-driver-4.png",
 )
